Package: fuzzyurn
Type: Package
Title: Generalized Non-Central Fuzzy Dynamic Hypergeometric Processes
Version: 0.1.0
Authors@R: person("Okechukwu J.", "Obulezi", 
                  email = "oj.obulezi@unizik.edu.ng", 
                  role = c("aut", "cre"),
                  comment = c(ORCID = "0000-0002-7753-1868"))
Description: Implements Generalized Non-Central Fuzzy Dynamic Hypergeometric Processes. 
    Includes discrete Markov chain sampling under dynamic weight decay and continuous 
    fuzzy membership maps, infinitesimal generator evaluation, weak convergence to Itô 
    diffusion SDEs, numerical solutions for Fokker-Planck PDEs, stationary Gibbs-Boltzmann 
    densities, and Azuma-Hoeffding concentration bounds.
License: GPL (>= 3)
Encoding: UTF-8
Imports: stats
Suggests: deSolve, graphics, testthat (>= 3.0.0)
Config/testthat/edition: 3
Config/roxygen2/version: 8.1.0
NeedsCompilation: no
Packaged: 2026-08-19 22:20:47 UTC; Dr. O. J. Obulezi
Author: Okechukwu J. Obulezi [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-7753-1868>)
Maintainer: Okechukwu J. Obulezi <oj.obulezi@unizik.edu.ng>
Repository: CRAN
Date/Publication: 2026-08-21 13:30:20 UTC
Built: R 4.6.0; ; 2026-08-21 13:59:32 UTC; unix
