#' @title Non-Asymptotic Azuma-Hoeffding Concentration Bound
#' @description Computes tail upper bound P(|X_n - E[X_n]| >= epsilon).
#' @param epsilon Numeric. Deviation threshold.
#' @param n Integer. Sample draw size.
#' @param M_mu Numeric. Upper bound on fuzzy membership measure. Default is 1.0.
#' @return Upper bound probability value.
#' @export
fuzzyurn_bound <- function(epsilon, n, M_mu = 1.0) {
  bound <- 2 * exp(-2 * (epsilon^2) / (n * (M_mu^2)))
  return(min(1.0, bound))
}
