% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/concentration_bounds.R
\name{fuzzyurn_bound}
\alias{fuzzyurn_bound}
\title{Non-Asymptotic Azuma-Hoeffding Concentration Bound}
\usage{
fuzzyurn_bound(epsilon, n, M_mu = 1)
}
\arguments{
\item{epsilon}{Numeric. Deviation threshold.}

\item{n}{Integer. Sample draw size.}

\item{M_mu}{Numeric. Upper bound on fuzzy membership measure. Default is 1.0.}
}
\value{
Upper bound probability value.
}
\description{
Computes tail upper bound P(|X_n - E[X_n]| >= epsilon).
}
