% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fuzzyurn-package.R
\docType{package}
\name{fuzzyurn-package}
\alias{fuzzyurn}
\alias{fuzzyurn-package}
\title{fuzzyurn: Generalized Non-Central Fuzzy Dynamic Hypergeometric Processes}
\description{
Implements Generalized Non-Central Fuzzy Dynamic Hypergeometric Processes. Includes discrete Markov chain sampling under dynamic weight decay and continuous fuzzy membership maps, infinitesimal generator evaluation, weak convergence to Itô diffusion SDEs, numerical solutions for Fokker-Planck PDEs, stationary Gibbs-Boltzmann densities, and Azuma-Hoeffding concentration bounds.
}
\author{
\strong{Maintainer}: Okechukwu J. Obulezi \email{oj.obulezi@unizik.edu.ng} (\href{https://orcid.org/0000-0002-7753-1868}{ORCID})

Authors:
\itemize{
  \item Okechukwu J. Obulezi \email{oj.obulezi@unizik.edu.ng} (\href{https://orcid.org/0000-0002-7753-1868}{ORCID})
}

}
\keyword{internal}
