% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fokker_planck.R
\name{fuzzyurn_stationary}
\alias{fuzzyurn_stationary}
\title{Stationary Invariant Gibbs-Boltzmann Density}
\usage{
fuzzyurn_stationary(y_grid, N, drift_fn, diff_fn)
}
\arguments{
\item{y_grid}{Vector. Discretized grid on [0, 1].}

\item{N}{Integer. Population size.}

\item{drift_fn}{Function b(y).}

\item{diff_fn}{Function a(y).}
}
\value{
Vector of normalized density values over `y_grid`.
}
\description{
Computes exact invariant potential landscape density p_infinity(y).
}
